Authors
=======

This file contains the list of people involved in the development
of pypt along its history.

* Grzegorz Śliwiński
* Agnieszka Głąbała
* Andrzej Bistram
* Veronica Zgirvaci
* Tomasz Święcicki
